@@ -11,4 +11,6 @@ fake_function <- function() {
   httr2::request
   odbc::dbConnect
   jsonlite::toJSON
+  stringr::str_escape
+  lifecycle::deprecate_warn
 }
