@@ -710,6 +710,16 @@ Telemetry <- R6::R6Class( # nolint object_name.
       checkmate::assert_character(excluded_inputs, null.ok = TRUE)
       checkmate::assert_character(excluded_inputs_regex, null.ok = TRUE)
 
+      checkmate::assert(
+        tryCatch({
+          lapply(excluded_inputs_regex, regexpr, text = "mock_text")
+          TRUE
+        }, error = function(err) "Regular expression is not valid"),
+        .var.name = "excluded_inputs_regex"
+      )
+
+      merged_regex <- merge_excluded_regex(excluded_inputs_regex)
+
       if (is.null(navigation_inputs)) {
         navigation_inputs <- c()
       }
@@ -754,15 +764,8 @@ Telemetry <- R6::R6Class( # nolint object_name.
 
           # Filter out excluded inputs by regular expression
           if (length(excluded_inputs_regex) > 0) {
-            excluded_inputs_regex <- excluded_inputs_regex %>%
-              purrr::map_chr(trimws) %>%
-              purrr::keep(~ nzchar(.x))  %>%
-              purrr::map_chr(stringr::str_escape) %>%
-              paste(collapse = "|") %>%
-              sub(pattern = "\\|$", replacement = "")
             filtered_names <- setdiff(
-              filtered_names,
-              grep(excluded_inputs_regex, filtered_names, value = TRUE)
+              filtered_names, grep(merged_regex, filtered_names, value = TRUE)
             )
           }
 
